/*
  LiquidCrystal +  LIDAR Lite Sensor By Pierluigi De Palo // Fab Academy 2015

 Demonstrates the use a 16x2 LCD display.  The LiquidCrystal
 library works with all LCD displays that are compatible with the
 Hitachi HD44780 driver. There are many of them out there, and you
 can usually tell them by the 16-pin interface.


  The circuit:
  
  For the LCD
  
 * LCD RS pin to digital pin 7
 * LCD Enable pin to digital pin 8
 * LCD D4 pin to digital pin 9
 * LCD D5 pin to digital pin 10
 * LCD D6 pin to digital pin 11
 * LCD D7 pin to digital pin 12
 * LCD R/W pin to ground
 * LCD VSS pin to ground
 * LCD VCC pin to 5V
 * ends to +5V and ground
 * wiper to LCD VO pin (pin 3)

 Library originally added 18 Apr 2008 by David A. Mellis 
 Modified 5 Jul 2009 by Limor Fried (http://www.ladyada.net)
 Example added 9 Jul 2009 by Tom Igoe modified 22 Nov 2010 by Tom Igoe

 This example code is in the public domain. http://www.arduino.cc/en/Tutorial/LiquidCrystal
 
 For the Lidar Lite Distance Sensor:
 
 * Lidar Lite GND
 * Lidar Lite SDA
 * Lidar Lite SCL
 * Lidar Lite MODE no pin
 * Lidar Lite PWR EN no pin
 * Lidar 5V
 
 */

// include the library code:
#include <LiquidCrystal.h>

#include <I2C.h>
#define    LIDARLite_ADDRESS   0x62          // Default I2C Address of LIDAR-Lite.
#define    RegisterMeasure     0x00          // Register to write to initiate ranging.
#define    MeasureValue        0x04          // Value to initiate ranging.
#define    RegisterHighLowB    0x8f          // Register to get both High and Low bytes in 1 call.


 // initialize the library with the numbers of the interface pins
LiquidCrystal lcd(7, 8, 9, 10, 11, 12);

void setup() {
  
  lcd.begin(16, 2); // set up the LCD's number of columns and rows:
  
  I2c.begin(); // Opens & joins the irc bus as master
  delay(500); // Waits to make sure everything is powered up before sending or receiving data  
  I2c.timeOut(50); // Sets a timeout to ensure no locking up of sketch if I2C communication fails
}

void loop() {
  
   // Write 0x04 to register 0x00
  uint8_t nackack = 100; // Setup variable to hold ACK/NACK resopnses     
  while (nackack != 0){ // While NACK keep going (i.e. continue polling until sucess message (ACK) is received )
    nackack = I2c.write(LIDARLite_ADDRESS,RegisterMeasure, MeasureValue); // Write 0x04 to 0x00
    delay(1); // Wait 1 ms to prevent overpolling
  }
   byte distanceArray[2]; // array to store distance bytes from read function
  
  // Read 2byte distance from register 0x8f
  nackack = 100; // Setup variable to hold ACK/NACK resopnses     
  while (nackack != 0){ // While NACK keep going (i.e. continue polling until sucess message (ACK) is received )
    nackack = I2c.read(LIDARLite_ADDRESS,RegisterHighLowB, 2, distanceArray); // Read 2 Bytes from LIDAR-Lite Address and store in array
    delay(1); // Wait 1 ms to prevent overpolling
  }
  
  int distance = (distanceArray[0] << 8) + distanceArray[1];  // Shift high byte [0] 8 to the left and add low byte [1] to create 16-bit int
  
  
  lcd.setCursor(6, 1);  // set the cursor to column and line   // (note: line 1 is the second row, since counting begins with 0):
  lcd.clear();
  lcd.print("DISTANCE Cm:");
  lcd.print(distance); // Print Distance
  
  
  delay(500);
  
  
}

